@@ -1126,9 +1126,9 @@ remglob (char **argv, int doswitch)
 }
 
 char *
-onoff (int bool)
+onoff (int val)
 {
-  return (bool ? "on" : "off");
+  return (val ? "on" : "off");
 }
 
 /*
@@ -2303,21 +2303,25 @@ setnmap (int argc, char **argv)
     }
   mapflag = 1;
   code = 1;
-  cp = strchr (altarg, ' ');
+  cp = altarg;
+  while (*cp && !isblank (*cp))
+    cp++;
   if (proxy)
     {
-      while (*++cp == ' ')
-	continue;
+      while (*cp && isblank(*cp))
+	cp++;
       altarg = cp;
-      cp = strchr (altarg, ' ');
+      while (*cp && !isblank (*cp))
+	cp++;
     }
   *cp = '\0';
 
   free (mapin);
   mapin = strdup (altarg);
 
-  while (*++cp == ' ')
-    continue;
+  do
+    cp++;
+  while (*cp && isblank(*cp));
   free (mapout);
   mapout = strdup (cp);
 }
