@@ -1,7 +1,5 @@
 /*
-  Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
-  2018, 2019, 2020, 2021 Free Software Foundation, Inc.
+  Copyright (C) 1998-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -48,7 +46,7 @@
 #endif
 
 #include <argp.h>
-#include <unused-parameter.h>
+#include <attribute.h>
 #include <ping.h>
 #include "ping_impl.h"
 #include "libinetutils.h"
@@ -381,7 +379,7 @@ decode_ip_timestamp (char *arg)
 int volatile stop = 0;
 
 void
-sig_int (int signal _GL_UNUSED_PARAMETER)
+sig_int (int signal MAYBE_UNUSED)
 {
   stop = 1;
 }
