@@ -382,7 +382,7 @@ bi_lookup (const struct servtab *sep)
 #endif
 
 void
-signal_set_handler (int signo, void (*handler) ())
+signal_set_handler (int signo, void (*handler) (int))
 {
 #if defined HAVE_SIGACTION
   struct sigaction sa;
